==> helper-8.x-1.28.tar.gz: helper/src/Utility.php <==
<?php

namespace Drupal\helper;

/**
 * Provides various utility helpers.
 */
class Utility {

  /**
   * Registers a unique function call for execution on shutdown.
   *
   * Wrapper for drupal_register_shutdown_function() that does not add the
   * function call if it already exists in the shutdown function stack.
   *
   * @param callable $callback
   *   The shutdown function to register.
   * @param ...
   *   Additional arguments to pass to the shutdown function.
   *
   * @return bool
   *   TRUE if the function was added, or FALSE if it was already in the stack.
   *
   * @see drupal_register_shutdown_function()
   */
  public static function registerUniqueShutdownFunction(callable $callback = NULL) {
    $args = func_get_args();
    array_shift($args);

    $existing_callbacks = drupal_register_shutdown_function();
    foreach ($existing_callbacks as $existing_callback) {
      if ($existing_callback['callback'] === $callback && $existing_callback['arguments'] === $args) {
        return FALSE;
      }
    }

    array_unshift($args, $callback);
    call_user_func_array('drupal_register_shutdown_function', $args);
    return TRUE;
  }

  /**
   * Runs a batch even if another batch is currently running.
   *
   * This is useful for running a batch inside another batch process.
   *
   * @param array $batch
   *   A batch array that would normally get passed to batch_set().
   */
  public static function runBatch(array $batch) {
    $existing_batch = batch_get();
    $current_batch = &batch_get();
    if ($existing_batch) {
      $current_batch = NULL;
    }
    batch_set($batch);
    $current_batch['progressive'] = FALSE;
    batch_process();
    if ($existing_batch) {
      $current_batch = $existing_batch;
    }
  }

  /**
   * Tests if a command exists on the server.
   *
   * @param string $command
   *   The command to test for.
   *
   * @return bool
   *   TRUE if the command exists, or FALSE otherwise.
   */
  public static function commandExists(string $command): bool {
    $command = escapeshellcmd($command);
    return (bool) shell_exec("command -v {$command}");
  }

  /**
   * Runs a composer command.
   *
   * Note: USE THIS AT YOUR OWN RISK. YOU ARE RESPONSIBLE FOR ESCAPING THE
   * INPUT TO THE $command PARAMETER.
   *
   * @param string $command
   *   The composer command to run, without the "composer" part.
   * @param string $additional
   *   The additonal command parameters and arguments.
   * @param mixed $result_code
   *   The result code from running the command, modified by reference.
   *
   * @throws \RuntimeException
   */
  public static function execCommand(string $command, string $additional, mixed &$result_code = NULL): void {
    if (Utility::commandExists($command)) {
      // @todo Should this be using passthru() or shell_exec() instead?
      $result = passthru("$command $additional", $result_code);
      if ($result === FALSE || $result_code) {
        throw new \RuntimeException("Failed running {$command} {$additional}.");
      }
    }
    else {
      throw new \RuntimeException("The {$command} command does not exist.");
    }
  }

}

==> helper-8.x-1.30.tar.gz: helper/src/Utility.php <==
<?php

namespace Drupal\helper;

use DrupalEnvironment\Environment;

/**
 * Provides various utility helpers.
 */
class Utility {

  /**
   * Registers a unique function call for execution on shutdown.
   *
   * Wrapper for drupal_register_shutdown_function() that does not add the
   * function call if it already exists in the shutdown function stack.
   *
   * @param callable $callback
   *   The shutdown function to register.
   * @param ...
   *   Additional arguments to pass to the shutdown function.
   *
   * @return bool
   *   TRUE if the function was added, or FALSE if it was already in the stack.
   *
   * @see drupal_register_shutdown_function()
   */
  public static function registerUniqueShutdownFunction(callable $callback = NULL) {
    $args = func_get_args();
    array_shift($args);

    $existing_callbacks = drupal_register_shutdown_function();
    foreach ($existing_callbacks as $existing_callback) {
      if ($existing_callback['callback'] === $callback && $existing_callback['arguments'] === $args) {
        return FALSE;
      }
    }

    array_unshift($args, $callback);
    call_user_func_array('drupal_register_shutdown_function', $args);
    return TRUE;
  }

  /**
   * Runs a batch even if another batch is currently running.
   *
   * This is useful for running a batch inside another batch process.
   *
   * @param array $batch
   *   A batch array that would normally get passed to batch_set().
   */
  public static function runBatch(array $batch) {
    $existing_batch = batch_get();
    $current_batch = &batch_get();
    if ($existing_batch) {
      $current_batch = NULL;
    }
    batch_set($batch);
    $current_batch['progressive'] = FALSE;
    batch_process();
    if ($existing_batch) {
      $current_batch = $existing_batch;
    }
  }

  /**
   * Runs a composer command.
   *
   * Note: USE THIS AT YOUR OWN RISK. YOU ARE RESPONSIBLE FOR ESCAPING THE
   * INPUT TO THE $command PARAMETER.
   *
   * @param string $command
   *   The composer command to run, without the "composer" part.
   * @param string $additional
   *   The additional command parameters and arguments.
   * @param mixed $result_code
   *   The result code from running the command, modified by reference.
   *
   * @throws \RuntimeException
   */
  public static function execCommand(string $command, string $additional, mixed &$result_code = NULL): void {
    if (Environment::commandExists($command)) {
      // @todo This should be using shell_exec().
      $result = passthru("$command $additional", $result_code);
      if ($result === FALSE || $result_code) {
        throw new \RuntimeException("Failed running {$command} {$additional}.");
      }
    }
    else {
      throw new \RuntimeException("The {$command} command does not exist.");
    }
  }

}
